@@ -806,7 +806,7 @@ if(hasBiomartConnection){
 ### code chunk number 101: BiomartGeneRegionTrackCustom
 ###################################################
 library(biomaRt)
-bm <- useMart(host="oct2012.archive.ensembl.org", biomart="ENSEMBL_MART_ENSEMBL",
+bm <- useMart(host="may2012.archive.ensembl.org", biomart="ENSEMBL_MART_ENSEMBL",
               dataset="hsapiens_gene_ensembl")
 fm <- Gviz:::.getBMFeatureMap()
 fm["symbol"] <- "external_gene_id"
